# Flips solver library

The Flips solver solves classical and augmented chemical reaction networks, as described in the publication

*Beyond the chemical master equation: stochastic chemical kinetics coupled with auxiliary processes*

## Installation

The package is installed by running:

    pip install flips

## Tutorial

A simple introductory tutorial is available in the Tutorial IPython notebook.